@@ -9,26 +9,26 @@
 #' @param p coverage level of tolerance bound (default = 0.99)
 #' @param B number of bootstrap samples (default = 500)
 #' @param no number of principal components (default = 5)
+#' @param Nsamp number of functions per bootstrap (default = 100)
 #' @param parallel enable parallel processing (default = T)
 #' @return Returns a list containing \item{amp}{amplitude tolerance bounds}
 #' \item{ph}{phase tolerance bounds}
 #' @keywords tolerance bootstrap
 #' @concept bounds
-#' @references J. D. Tucker, J. R. Lewis, C. King, and S. Kurtek,
-#'   “A Geometric Approach for Computing Tolerance Bounds for Elastic Functional Data,”
-#'    Journal of Applied Statistics, 10.1080/02664763.2019.1645818, 2019.
-#' @references Tucker, J. D., Wu, W., Srivastava, A.,
-#'  Generative Models for Function Data using Phase and Amplitude Separation,
-#'  Computational Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001.
-#' @references Jung, S. L. a. S. (2016). "Combined Analysis of Amplitude and Phase Variations in Functional Data."
-#'        	arXiv:1603.01775 [stat.ME].
+#' @references J. D. Tucker, J. R. Lewis, C. King, and S. Kurtek, “A Geometric
+#'   Approach for Computing Tolerance Bounds for Elastic Functional Data,”
+#'   Journal of Applied Statistics, 10.1080/02664763.2019.1645818, 2019.
+#' @references Tucker, J. D., Wu, W., Srivastava, A., Generative Models for
+#'   Function Data using Phase and Amplitude Separation, Computational
+#'   Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001.
+#' @references Jung, S. L. a. S. (2016). "Combined Analysis of Amplitude and
+#'   Phase Variations in Functional Data." arXiv:1603.01775.
 #' @export
 #' @examples
 #' \dontrun{
-#'   data("simu_data")
-#'   out1 = bootTB(simu_data$f,simu_data$time)
+#'   out1 <- bootTB(simu_data$f, simu_data$time)
 #' }
-bootTB <- function(f, time, a=.05, p=.99, B=500, no = 5, parallel=T){
+bootTB <- function(f, time, a=.05, p=.99, B=500, no = 5, Nsamp=100, parallel=T){
 
   M <- nrow(f)
   N <- ncol(f)
@@ -52,7 +52,7 @@ bootTB <- function(f, time, a=.05, p=.99, B=500, no = 5, parallel=T){
   k = 1
   pb <- txtProgressBar(0, B, style = 3)
   outfor <- foreach(k=1:B, .combine=cbind, .packages=c('fdasrvf','mvtnorm')) %dopar% {
-    samples <- joint_gauss_model(out.med, 100, no)
+    samples <- joint_gauss_model(out.med, Nsamp, no)
     amp <- AmplitudeBoxplot(samples, alpha=1-p, showplot=F)
     ph <- PhaseBoxplot(samples, alpha=1-p, showplot=F)
     setTxtProgressBar(pb, k)
@@ -100,19 +100,18 @@ bootTB <- function(f, time, a=.05, p=.99, B=500, no = 5, parallel=T){
 #' @return Returns a list containing \item{pca}{pca output}
 #' \item{tol}{tolerance factor}
 #' @concept pca tolerance bounds
-#' @references J. D. Tucker, J. R. Lewis, C. King, and S. Kurtek,
-#'   “A Geometric Approach for Computing Tolerance Bounds for Elastic Functional Data,”
-#'    Journal of Applied Statistics, 10.1080/02664763.2019.1645818, 2019.
-#' @references Tucker, J. D., Wu, W., Srivastava, A.,
-#'  Generative Models for Function Data using Phase and Amplitude Separation,
-#'  Computational Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001.
-#' @references Jung, S. L. a. S. (2016). "Combined Analysis of Amplitude and Phase Variations in Functional Data."
-#'        	arXiv:1603.01775 [stat.ME].
+#' @references J. D. Tucker, J. R. Lewis, C. King, and S. Kurtek, “A Geometric
+#'   Approach for Computing Tolerance Bounds for Elastic Functional Data,”
+#'   Journal of Applied Statistics, 10.1080/02664763.2019.1645818, 2019.
+#' @references Tucker, J. D., Wu, W., Srivastava, A., Generative Models for
+#'   Function Data using Phase and Amplitude Separation, Computational
+#'   Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001.
+#' @references Jung, S. L. a. S. (2016). "Combined Analysis of Amplitude and
+#'   Phase Variations in Functional Data." arXiv:1603.01775.
 #' @export
 #' @examples
 #' \dontrun{
-#'   data("simu_data")
-#'   out1 = pcaTB(simu_data$f,simu_data$time)
+#'   out1 <- pcaTB(simu_data$f, simu_data$time)
 #' }
 pcaTB <- function(f, time, m = 4, B = 100000, a = 0.05, p = 0.99){
   # Align Data --------------------------------------------------------------
