@@ -1,5 +1,8 @@
 
 #include "DriverElasticCurvesRO.h"
+#ifndef PI
+  #define PI 3.14159265358979323846
+#endif
 
 /*Define the namespace*/
 namespace ROPTLIB{
